@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
-from contextlib import suppress
+from contextlib import ContextDecorator, ExitStack, contextmanager, suppress
 from dataclasses import dataclass, field
+from typing import ContextManager
 from weakref import WeakSet
 
 __all__ = ("Event", "EventChannel", "EventListener")
@@ -14,7 +15,7 @@ class EventListener(ABC):
     __slots__ = ("__weakref__",)
 
     @abstractmethod
-    def on_event(self, event: Event, /):
+    def on_event(self, event: Event, /) -> ContextManager | None:
         raise NotImplementedError
 
 
@@ -22,11 +23,18 @@ class EventListener(ABC):
 class EventChannel:
     __listeners: WeakSet[EventListener] = field(default_factory=WeakSet, init=False)
 
-    def dispatch(self, event: Event):
-        for listener in self.__listeners:
-            listener.on_event(event)
+    @contextmanager
+    def dispatch(self, event: Event) -> ContextManager | ContextDecorator:
+        with ExitStack() as stack:
+            for listener in tuple(self.__listeners):
+                context_manager = listener.on_event(event)
 
-        return self
+                if context_manager is None:
+                    continue
+
+                stack.enter_context(context_manager)
+
+            yield
 
     def add_listener(self, listener: EventListener):
         self.__listeners.add(listener)
